Module fingerprint

Module fingerprint 

Functions

compute_content_hash
Compute SHA-256 hash of content and return as hex string
get_file_mtime_secs
Get the modification time of a file in seconds since epoch. Returns None if the file metadata cannot be read.