pub struct CachedSpec {
pub cache_format_version: u32,
pub name: String,
pub version: String,
pub commands: Vec<CachedCommand>,
pub base_url: Option<String>,
pub servers: Vec<String>,
pub security_schemes: HashMap<String, CachedSecurityScheme>,
pub skipped_endpoints: Vec<SkippedEndpoint>,
pub server_variables: HashMap<String, ServerVariable>,
}Fields
cache_format_version: u32Cache format version to detect incompatible changes
name: Stringversion: Stringcommands: Vec<CachedCommand>base_url: Option<String>Base URL extracted from the first server in the OpenAPI spec
servers: Vec<String>All server URLs from the OpenAPI spec for future multi-environment support
security_schemes: HashMap<String, CachedSecurityScheme>Security schemes defined in the OpenAPI spec with x-aperture-secret mappings
skipped_endpoints: Vec<SkippedEndpoint>Endpoints skipped during validation due to unsupported features (added in v0.1.2)
server_variables: HashMap<String, ServerVariable>Server variables defined in the OpenAPI spec for URL template resolution (added in v0.1.3)