Handlers for aperture config * subcommands.
Functions
- clear_
response_ cache - Clear response cache for a specific API or all APIs
- execute_
config_ command - Execute
aperture config <subcommand>. - handle_
list_ mappings - Handle the
config list-mappingscommand - handle_
remove_ mapping - Handle the
config remove-mappingcommand - handle_
set_ mapping - Handle the
config set-mappingcommand - list_
specs_ with_ details - print_
api_ url_ entry - Print a single API URL entry in the list
- print_
secrets_ list - Print the list of configured secrets for an API
- print_
settings_ list - print_
url_ configuration - Print URL configuration for a specific API
- reinit_
all_ specs - reinit_
spec - show_
cache_ stats - Show cache statistics for a specific API or all APIs
- validate_
api_ name - Validates and returns the API context name, returning an error for invalid names.