pub fn generate_command_tree_with_flags(
spec: &CachedSpec,
use_positional_args: bool,
) -> CommandExpand description
Generates a dynamic clap command tree with optional legacy positional parameter syntax.
pub fn generate_command_tree_with_flags(
spec: &CachedSpec,
use_positional_args: bool,
) -> CommandGenerates a dynamic clap command tree with optional legacy positional parameter syntax.