pub struct OsFileSystem;Trait Implementations
Sourceimpl FileSystem for OsFileSystem
impl FileSystem for OsFileSystem
Sourcefn read_to_string(&self, path: &Path) -> Result<String>
fn read_to_string(&self, path: &Path) -> Result<String>
Reads the entire contents of a file into a string. Read more
Sourcefn write_all(&self, path: &Path, contents: &[u8]) -> Result<()>
fn write_all(&self, path: &Path, contents: &[u8]) -> Result<()>
Writes a slice of bytes to a file, creating the file if it does not exist. Read more
Sourcefn create_dir_all(&self, path: &Path) -> Result<()>
fn create_dir_all(&self, path: &Path) -> Result<()>
Creates a directory and all of its parent components if they are missing. Read more
Sourcefn remove_file(&self, path: &Path) -> Result<()>
fn remove_file(&self, path: &Path) -> Result<()>
Removes a file from the filesystem. Read more
Sourcefn remove_dir_all(&self, path: &Path) -> Result<()>
fn remove_dir_all(&self, path: &Path) -> Result<()>
Removes a directory and all of its contents. Read more
Sourcefn is_dir(&self, path: &Path) -> bool
fn is_dir(&self, path: &Path) -> bool
Returns
true if the path exists and is pointing at a directory.Sourcefn is_file(&self, path: &Path) -> bool
fn is_file(&self, path: &Path) -> bool
Returns
true if the path exists and is pointing at a regular file.Sourcefn canonicalize(&self, path: &Path) -> Result<PathBuf>
fn canonicalize(&self, path: &Path) -> Result<PathBuf>
Returns the canonical, absolute form of the path with all intermediate components normalized. Read more