Modules
Functions
- confirm
- Ask for user confirmation with yes/no prompt
- confirm_
exit - Prompts for confirmation to exit/cancel an interactive session
- confirm_
with_ io - Testable version of
confirmthat accepts anInputOutputtrait - confirm_
with_ io_ and_ timeout - Testable version of
confirmwith configurable timeout - confirm_
with_ timeout - Ask for user confirmation with yes/no prompt and timeout
- handle_
cancellation_ input - Checks if the user wants to cancel the current operation This is called when empty input is provided as a cancellation signal
- prompt_
for_ input - Prompt the user for input with the given prompt message
- prompt_
for_ input_ with_ io - Testable version of
prompt_for_inputthat accepts anInputOutputtrait - prompt_
for_ input_ with_ io_ and_ timeout - Testable version of
prompt_for_inputwith configurable timeout - prompt_
for_ input_ with_ timeout - Prompt the user for input with a custom timeout
- select_
from_ options - Present a menu of options and return the selected value
- select_
from_ options_ with_ io - Testable version of
select_from_optionsthat accepts anInputOutputtrait - select_
from_ options_ with_ io_ and_ timeout - Testable version of
select_from_optionswith configurable timeout - select_
from_ options_ with_ timeout - Present a menu of options with timeout and return the selected value
- validate_
env_ var_ name - Validates an environment variable name