prompt_for_input

Function prompt_for_input 

pub fn prompt_for_input(prompt: &str) -> Result<String, Error>
Prompt the user for input with the given prompt message

Errors

Returns an error if stdin/stdout operations fail, input is too long, contains invalid characters, or times out