select_from_options

Function select_from_options 

pub fn select_from_options(
    prompt: &str,
    options: &[(String, String)],
) -> Result<String, Error>
Present a menu of options and return the selected value

Errors

Returns an error if no options are provided, if stdin operations fail, or if maximum retry attempts are exceeded