Module response_cache

Module response_cache 

Structs

CacheConfig
Configuration for response caching
CacheKey
Cache key components for generating cache file names
CacheStats
Cache statistics
CachedRequestInfo
Information about the request that generated a cached response
CachedResponse
A cached API response
ResponseCache
Response cache manager

Functions

is_auth_header
Check if a header is an authentication header that should be excluded from caching
scrub_auth_headers
Scrub authentication headers from a header map before caching.