JQ-based value extraction from operation responses.
Applies JQ queries from capture and capture_append fields to an
operation’s response body and stores results in the VariableStore.
Functions
- extract_
captures - Extracts captured values from a response and stores them in the variable store.