Module config

Module config 

Handlers for aperture config * subcommands.

Functions

clear_response_cache
Clear response cache for a specific API or all APIs
execute_config_command
Execute aperture config <subcommand>.
handle_list_mappings
Handle the config list-mappings command
handle_remove_mapping
Handle the config remove-mapping command
handle_set_mapping
Handle the config set-mapping command
list_specs_with_details
print_api_url_entry
Print a single API URL entry in the list
print_secrets_list
Print the list of configured secrets for an API
print_settings_list
print_url_configuration
Print URL configuration for a specific API
reinit_all_specs
reinit_spec
show_cache_stats
Show cache statistics for a specific API or all APIs
validate_api_name
Validates and returns the API context name, returning an error for invalid names.