pub struct Cli {Show 19 fields
pub describe_json: bool,
pub json_errors: bool,
pub quiet: bool,
pub dry_run: bool,
pub idempotency_key: Option<String>,
pub format: OutputFormat,
pub jq: Option<String>,
pub batch_file: Option<String>,
pub batch_concurrency: usize,
pub batch_rate_limit: Option<u32>,
pub cache: bool,
pub no_cache: bool,
pub cache_ttl: Option<u64>,
pub positional_args: bool,
pub retry: Option<u32>,
pub retry_delay: Option<String>,
pub retry_max_delay: Option<String>,
pub force_retry: bool,
pub command: Commands,
}Fields
describe_json: boolOutput a JSON manifest of all available commands and parameters
json_errors: boolOutput all errors as structured JSON to stderr When used with batch operations, outputs a clean JSON summary at the end
quiet: boolSuppress non-essential output (success messages, tips, hints) Only outputs requested data and errors
dry_run: boolShow the HTTP request that would be made without executing it
idempotency_key: Option<String>Set the Idempotency-Key header for safe retries
format: OutputFormatOutput format for response data
jq: Option<String>Apply JQ filter to response data, describe-json output, or batch results (with –json-errors)
batch_file: Option<String>Execute operations from a batch file
batch_concurrency: usizeMaximum concurrent requests for batch operations
batch_rate_limit: Option<u32>Rate limit for batch operations (requests per second)
cache: boolEnable response caching
no_cache: boolDisable response caching
cache_ttl: Option<u64>TTL for cached responses in seconds
positional_args: boolUse positional arguments for path parameters (legacy syntax)
retry: Option<u32>Maximum number of retry attempts for failed requests
retry_delay: Option<String>Initial delay between retries (e.g., “500ms”, “1s”)
retry_max_delay: Option<String>Maximum delay cap between retries (e.g., “30s”, “1m”)
force_retry: boolForce retry on non-idempotent requests without an idempotency key
command: CommandsTrait Implementations
Sourceimpl Args for Cli
impl Args for Cli
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for Cli
impl CommandFactory for Cli
Sourceimpl FromArgMatches for Cli
impl FromArgMatches for Cli
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.