pub struct Cli {Show 14 fields
pub describe_json: bool,
pub json_errors: bool,
pub dry_run: bool,
pub idempotency_key: Option<String>,
pub format: OutputFormat,
pub jq: Option<String>,
pub batch_file: Option<String>,
pub batch_concurrency: usize,
pub batch_rate_limit: Option<u32>,
pub cache: bool,
pub no_cache: bool,
pub cache_ttl: Option<u64>,
pub positional_args: bool,
pub command: Commands,
}Fields
describe_json: boolOutput a JSON manifest of all available commands and parameters
json_errors: boolOutput all errors as structured JSON to stderr When used with batch operations, outputs a clean JSON summary at the end
dry_run: boolShow the HTTP request that would be made without executing it
idempotency_key: Option<String>Set the Idempotency-Key header for safe retries
format: OutputFormatOutput format for response data
jq: Option<String>Apply JQ filter to response data, describe-json output, or batch results (with –json-errors)
batch_file: Option<String>Execute operations from a batch file
batch_concurrency: usizeMaximum concurrent requests for batch operations
batch_rate_limit: Option<u32>Rate limit for batch operations (requests per second)
cache: boolEnable response caching
no_cache: boolDisable response caching
cache_ttl: Option<u64>TTL for cached responses in seconds
positional_args: boolUse positional arguments for path parameters (legacy syntax)
command: CommandsTrait Implementations
Sourceimpl Args for Cli
impl Args for Cli
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for Cli
impl CommandFactory for Cli
Sourceimpl FromArgMatches for Cli
impl FromArgMatches for Cli
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for Cli
impl Parser for Cli
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)