pub enum SettingValue {
U64(u64),
Bool(bool),
}Expand description
Type-safe representation of a configuration setting value.
Variants
Implementations
Sourceimpl SettingValue
impl SettingValue
Sourcepub fn parse_for_key(key: SettingKey, value: &str) -> Result<Self, Error>
pub fn parse_for_key(key: SettingKey, value: &str) -> Result<Self, Error>
Parse a string value into the appropriate type for the given key.
Errors
Returns an error if the value cannot be parsed as the expected type, or if the value is outside the allowed range for the setting.