Module generator

Module generator 

Functions

generate_command_tree
Generates a dynamic clap command tree from a cached OpenAPI specification.
generate_command_tree_with_flags
Generates a dynamic clap command tree with optional legacy positional parameter syntax.