Error

Enum Error 

pub enum Error {
    Io(Error),
    Network(Error),
    Yaml(Error),
    Json(Error),
    Toml(Error),
    Internal {
        kind: ErrorKind,
        message: Cow<'static, str>,
        context: Option<ErrorContext>,
    },
    Anyhow(Error),
}

Variants



Io(Error)



Network(Error)



Yaml(Error)



Json(Error)



Toml(Error)



Internal

Fields

message: Cow<'static, str>


Anyhow(Error)

Implementations

Source

impl Error

pub fn with_context(self, context: &str) -> Self

Add context to an error for better user messaging

pub fn with_operation_context(self, operation: &str, api: &str) -> Self

Add operation context to an error for better debugging

pub fn with_suggestion(self, suggestion: &str) -> Self

Add suggestions to error messages for better user guidance

pub fn to_json(&self) -> JsonError

Convert error to JSON representation for structured output

Source

impl Error

pub fn spec_not_found(name: impl Into<String>) -> Self

Create a specification not found error

pub fn spec_already_exists(name: impl Into<String>) -> Self

Create a specification already exists error

pub fn cached_spec_not_found(name: impl Into<String>) -> Self

Create a cached spec not found error

pub fn cached_spec_corrupted( name: impl Into<String>, reason: impl Into<String>, ) -> Self

Create a cached spec corrupted error

pub fn cache_version_mismatch( name: impl Into<String>, found: u32, expected: u32, ) -> Self

Create a cache version mismatch error

pub fn secret_not_set( scheme_name: impl Into<String>, env_var: impl Into<String>, ) -> Self

Create a secret not set error

pub fn unsupported_auth_scheme(scheme: impl Into<String>) -> Self

Create an unsupported auth scheme error

pub fn unsupported_security_scheme(scheme_type: impl Into<String>) -> Self

Create an unsupported security scheme error

pub fn validation_error(message: impl Into<String>) -> Self

Create a generic validation error

pub fn invalid_config(reason: impl Into<String>) -> Self

Create an invalid configuration error

pub fn invalid_json_body(reason: impl Into<String>) -> Self

Create an invalid JSON body error

pub fn invalid_path(path: impl Into<String>, reason: impl Into<String>) -> Self

Create an invalid path error

pub fn request_failed(status: StatusCode, reason: impl Into<String>) -> Self

Create a request failed error

pub fn response_read_error(reason: impl Into<String>) -> Self

Create a response read error

pub fn invalid_http_method(method: impl Into<String>) -> Self

Create an invalid HTTP method error

pub fn invalid_header_name( name: impl Into<String>, reason: impl Into<String>, ) -> Self

Create an invalid header name error

pub fn invalid_header_value( name: impl Into<String>, reason: impl Into<String>, ) -> Self

Create an invalid header value error

pub fn invalid_header_format(header: impl Into<String>) -> Self

Create an invalid header format error

pub const fn empty_header_name() -> Self

Create an empty header name error

pub fn interactive_input_too_long(max_length: usize) -> Self

Create an interactive input too long error

pub fn interactive_invalid_characters( invalid_chars: impl Into<String>, suggestion: impl Into<String>, ) -> Self

Create an interactive invalid characters error

pub const fn interactive_timeout() -> Self

Create an interactive timeout error

pub fn interactive_retries_exhausted( max_retries: usize, last_error: impl Into<String>, suggestions: &[String], ) -> Self

Create an interactive retries exhausted error

pub fn missing_server_variable(name: impl Into<String>) -> Self

Create a missing server variable error

pub fn unknown_server_variable( name: impl Into<String>, available: &[String], ) -> Self

Create an unknown server variable error

pub fn unresolved_template_variable( name: impl Into<String>, url: impl Into<String>, ) -> Self

Create an unresolved template variable error

pub fn invalid_environment_variable_name( name: impl Into<String>, reason: impl Into<String>, suggestion: impl Into<String>, ) -> Self

Create an invalid environment variable name error with suggestion

pub fn invalid_server_var_format( arg: impl Into<String>, reason: impl Into<String>, ) -> Self

Create an invalid server variable format error

pub fn invalid_server_var_value( name: impl Into<String>, value: impl Into<String>, allowed_values: &[String], ) -> Self

Create an invalid server variable value error

pub fn operation_not_found(operation: impl Into<String>) -> Self

Create an operation not found error

pub fn operation_not_found_with_suggestions( operation: impl Into<String>, suggestions: &[String], ) -> Self

Create an operation not found error with suggestions

pub fn network_request_failed(reason: impl Into<String>) -> Self

Create a network request failed error

pub fn serialization_error(reason: impl Into<String>) -> Self

Create a serialization error

pub fn home_directory_not_found() -> Self

Create a home directory not found error

pub fn invalid_command( context: impl Into<String>, reason: impl Into<String>, ) -> Self

Create an invalid command error

pub fn http_error_with_context( status: u16, body: impl Into<String>, api_name: impl Into<String>, operation_id: Option<impl Into<String>>, security_schemes: &[String], ) -> Self

Create an HTTP error with context

pub fn jq_filter_error( filter: impl Into<String>, reason: impl Into<String>, ) -> Self

Create a JQ filter error

pub fn transient_network_error( reason: impl Into<String>, retryable: bool, ) -> Self

Create a transient network error

pub fn retry_limit_exceeded( max_attempts: u32, last_error: impl Into<String>, ) -> Self

Create a retry limit exceeded error

pub fn retry_limit_exceeded_detailed( max_attempts: u32, attempts_made: u32, last_error: impl Into<String>, initial_delay_ms: u64, max_delay_ms: u64, last_status_code: Option<u16>, operation_id: impl Into<String>, ) -> Self

Create a retry limit exceeded error with detailed retry information

pub fn request_timeout(timeout_seconds: u64) -> Self

Create a request timeout error

pub fn missing_path_parameter(name: impl Into<String>) -> Self

Create a missing path parameter error

pub fn io_error(message: impl Into<String>) -> Self

Create a general I/O error

pub const fn invalid_idempotency_key() -> Self

Create an invalid idempotency key error

pub const fn editor_not_set() -> Self

Create an editor not set error

pub fn editor_failed(name: impl Into<String>) -> Self

Create an editor failed error

pub fn unknown_setting_key(key: impl Into<String>) -> Self

Create an unknown setting key error

pub fn invalid_setting_value(key: SettingKey, value: impl Into<String>) -> Self

Create an invalid setting value error

pub fn setting_value_out_of_range( key: SettingKey, value: impl Into<String>, reason: &str, ) -> Self

Create a setting value out of range error