pub enum Error {
Show 49 variants
Io(Error),
Network(Error),
Yaml(Error),
Json(Error),
Toml(Error),
Config(String),
Validation(String),
SpecNotFound {
name: String,
},
SpecAlreadyExists {
name: String,
},
CachedSpecNotFound {
name: String,
},
CachedSpecCorrupted {
name: String,
reason: String,
},
CacheVersionMismatch {
name: String,
found: u32,
expected: u32,
},
SecretNotSet {
scheme_name: String,
env_var: String,
},
InvalidHeaderFormat {
header: String,
},
InvalidHeaderName {
name: String,
reason: String,
},
InvalidHeaderValue {
name: String,
reason: String,
},
EditorNotSet,
EditorFailed {
name: String,
},
InvalidHttpMethod {
method: String,
},
MissingPathParameter {
name: String,
},
UnsupportedAuthScheme {
scheme: String,
},
UnsupportedSecurityScheme {
scheme_type: String,
},
SerializationError {
reason: String,
},
InvalidConfig {
reason: String,
},
HomeDirectoryNotFound,
InvalidJsonBody {
reason: String,
},
RequestFailed {
reason: String,
},
ResponseReadError {
reason: String,
},
HttpErrorWithContext {
status: u16,
body: String,
api_name: String,
operation_id: Option<String>,
security_schemes: Vec<String>,
},
InvalidCommand {
context: String,
reason: String,
},
OperationNotFound,
InvalidIdempotencyKey,
EmptyHeaderName,
JqFilterError {
reason: String,
},
InvalidPath {
path: String,
reason: String,
},
InteractiveInputTooLong {
provided: usize,
max: usize,
suggestion: String,
},
InteractiveInvalidCharacters {
invalid_chars: String,
suggestion: String,
},
InteractiveTimeout {
timeout_secs: u64,
suggestion: String,
},
InteractiveRetriesExhausted {
max_attempts: usize,
last_error: String,
suggestions: Vec<String>,
},
InvalidEnvironmentVariableName {
name: String,
reason: String,
suggestion: String,
},
RequestTimeout {
attempts: usize,
timeout_ms: u64,
},
RetryLimitExceeded {
attempts: usize,
duration_ms: u64,
last_error: String,
},
TransientNetworkError {
reason: String,
retryable: bool,
},
MissingServerVariable {
name: String,
},
UnknownServerVariable {
name: String,
available: Vec<String>,
},
InvalidServerVarFormat {
arg: String,
reason: String,
},
InvalidServerVarValue {
name: String,
value: String,
allowed_values: Vec<String>,
},
UnresolvedTemplateVariable {
name: String,
url: String,
},
Anyhow(Error),
}Variants
Io(Error)
Network(Error)
Yaml(Error)
Json(Error)
Toml(Error)
Config(String)
Validation(String)
SpecNotFound
SpecAlreadyExists
CachedSpecNotFound
CachedSpecCorrupted
CacheVersionMismatch
SecretNotSet
InvalidHeaderFormat
InvalidHeaderName
InvalidHeaderValue
EditorNotSet
EditorFailed
InvalidHttpMethod
MissingPathParameter
UnsupportedAuthScheme
UnsupportedSecurityScheme
SerializationError
InvalidConfig
HomeDirectoryNotFound
InvalidJsonBody
RequestFailed
ResponseReadError
HttpErrorWithContext
Fields
InvalidCommand
OperationNotFound
InvalidIdempotencyKey
EmptyHeaderName
JqFilterError
InvalidPath
InteractiveInputTooLong
InteractiveInvalidCharacters
InteractiveTimeout
InteractiveRetriesExhausted
InvalidEnvironmentVariableName
RequestTimeout
RetryLimitExceeded
TransientNetworkError
MissingServerVariable
UnknownServerVariable
InvalidServerVarFormat
InvalidServerVarValue
UnresolvedTemplateVariable
Anyhow(Error)
Implementations
Sourceimpl Error
impl Error
Sourcepub fn with_context(self, context: &str) -> Self
pub fn with_context(self, context: &str) -> Self
Add context to an error for better user messaging
Sourcepub fn with_operation_context(self, operation: &str, api: &str) -> Self
pub fn with_operation_context(self, operation: &str, api: &str) -> Self
Add operation context to an error for better debugging
Sourcepub fn with_suggestion(self, suggestion: &str) -> Self
pub fn with_suggestion(self, suggestion: &str) -> Self
Add suggestions to error messages for better user guidance