Module interactive

Modules

mock

Functions

confirm
Ask for user confirmation with yes/no prompt
confirm_exit
Prompts for confirmation to exit/cancel an interactive session
confirm_with_io
Testable version of confirm that accepts an InputOutput trait
confirm_with_io_and_timeout
Testable version of confirm with configurable timeout
confirm_with_timeout
Ask for user confirmation with yes/no prompt and timeout
handle_cancellation_input
Checks if the user wants to cancel the current operation This is called when empty input is provided as a cancellation signal
prompt_for_input
Prompt the user for input with the given prompt message
prompt_for_input_with_io
Testable version of prompt_for_input that accepts an InputOutput trait
prompt_for_input_with_io_and_timeout
Testable version of prompt_for_input with configurable timeout
prompt_for_input_with_timeout
Prompt the user for input with a custom timeout
select_from_options
Present a menu of options and return the selected value
select_from_options_with_io
Testable version of select_from_options that accepts an InputOutput trait
select_from_options_with_io_and_timeout
Testable version of select_from_options with configurable timeout
select_from_options_with_timeout
Present a menu of options with timeout and return the selected value
validate_env_var_name
Validates an environment variable name