pub fn handle_cancellation_input() -> Result<bool, Error>Expand description
Checks if the user wants to cancel the current operation This is called when empty input is provided as a cancellation signal
Errors
Returns an error if the confirmation input operation fails