pub fn select_from_options_with_timeout(
prompt: &str,
options: &[(String, String)],
timeout: Duration,
) -> Result<String, Error>Expand description
Present a menu of options with timeout and return the selected value
Errors
Returns an error if no options are provided, if stdin operations fail, maximum retry attempts are exceeded, or timeout occurs