Structs
- Cache
Config - Configuration for response caching
- Cache
Key - Cache key components for generating cache file names
- Cache
Stats - Cache statistics
- Cached
Request Info - Information about the request that generated a cached response
- Cached
Response - A cached API response
- Response
Cache - Response cache manager
Functions
- is_
auth_ header - Check if a header is an authentication header that should be excluded from caching
- scrub_
auth_ headers - Scrub authentication headers from a header map before caching.