ShortcutResolver

Struct ShortcutResolver 

pub struct ShortcutResolver { /* private fields */ }
Command shortcut resolver

Implementations

Source

impl ShortcutResolver

pub fn new() -> Self

Create a new shortcut resolver

pub fn index_specs(&mut self, specs: &BTreeMap<String, CachedSpec>)

Index all available commands for shortcut resolution

pub fn resolve_shortcut(&self, args: &[String]) -> ResolutionResult

Resolve a command shortcut to full command path

Panics

Panics if candidates is empty when exactly one match is expected. This should not happen in practice due to the length check.

pub fn format_ambiguous_suggestions( &self, matches: &[ResolvedShortcut], ) -> String

Generate suggestions for ambiguous matches