pub struct SpecValidator;Expand description
Validates OpenAPI specifications for compatibility with Aperture
Implementations
Sourceimpl SpecValidator
impl SpecValidator
Sourcepub fn validate(&self, spec: &OpenAPI) -> Result<(), Error>
👎Deprecated since 0.1.2: Use validate_with_mode() instead. This method defaults to strict mode which may not be desired.
pub fn validate(&self, spec: &OpenAPI) -> Result<(), Error>
validate_with_mode() instead. This method defaults to strict mode which may not be desired.Validates an OpenAPI specification for Aperture compatibility
Errors
Returns an error if:
- The spec contains unsupported security schemes (
OAuth2,OpenIDConnect) - The spec uses $ref references in security schemes, parameters, or request bodies
- Required x-aperture-secret extensions are missing
- Parameters use content-based serialization
- Request bodies use non-JSON content types
Sourcepub fn validate_with_mode(
&self,
spec: &OpenAPI,
strict: bool,
) -> ValidationResult
pub fn validate_with_mode( &self, spec: &OpenAPI, strict: bool, ) -> ValidationResult